@@ -9,7 +9,7 @@ from rich.panel import Panel
 from rich.table import Table
 import rich
 
-from pycopilot.copilot import Copilot
+from pycopilot.copilot import Copilot  # type: ignore
 from pycopilot.auth import Authentication
 from .git import GitRepository, GitError, NotAGitRepositoryError, GitStatus
 from .settings import Settings
@@ -21,7 +21,7 @@ app = typer.Typer(help=__doc__, add_completion=False)
 
 def version_callback(value: bool):
     if value:
-        rich.print(f"git-copilot-version [bold green]{__version__}[/]")
+        rich.print(f"git-copilot-commit [bold green]{__version__}[/]")
         raise typer.Exit()
 
 
@@ -78,9 +78,13 @@ def generate_commit_message(
 ) -> str:
     """Generate a conventional commit message using Copilot API."""
 
-    # Get recent commits for context
-    recent_commits = repo.get_recent_commits(limit=5)
-    recent_commits_text = "\n".join([f"- {msg}" for _, msg in recent_commits])
+    # Get recent commits for context (handle empty repositories)
+    try:
+        recent_commits = repo.get_recent_commits(limit=5)
+        recent_commits_text = "\n".join([f"- {msg}" for _, msg in recent_commits])
+    except GitError:
+        # No commits yet in this repository
+        recent_commits_text = "No previous commits (initial commit)"
 
     client = Copilot(
         system_prompt="""
@@ -172,6 +176,7 @@ Return the commit message as the output without any additional text, explanation
     )
 
     prompt = f"""Recent commits:
+
 {recent_commits_text}
 
 `git status`:
@@ -201,9 +206,12 @@ def commit(
     model: str | None = typer.Option(
         None, "--model", "-m", help="Model to use for generating commit message"
     ),
+    yes: bool = typer.Option(
+        False, "--yes", "-y", help="Automatically accept the generated commit message"
+    ),
 ):
     """
-    Automatically commit changes in the current git repository.
+    Generate commit message based on changes in the current git repository and commit them.
     """
     try:
         repo = GitRepository()
@@ -260,10 +268,14 @@ def commit(
         raise typer.Exit()
 
     # Generate or use provided commit message
-    with console.status("[cyan]Generating commit message...[/cyan]"):
+    with console.status(
+        "[cyan]Generating commit message based on [bold]`git diff --staged`[/bold] ...[/cyan]"
+    ):
         commit_message = generate_commit_message(repo, status, model)
 
-    console.print("[cyan]Generated commit message...[/cyan]")
+    console.print(
+        "[cyan]Generated commit message based on [bold]`git diff --staged`[/bold] ...[/cyan]"
+    )
 
     # Display commit message
     console.print(Panel(commit_message, title="Commit Message", border_style="green"))
@@ -274,34 +286,42 @@ def commit(
         for file in status.staged_files:
             console.print(f"  {file.staged_status} {file.path}")
 
-    # Confirm commit or edit message
-    choice = typer.prompt(
-        "Choose action: (c)ommit, (e)dit message, (q)uit",
-        default="c",
-        show_default=True,
-    ).lower()
-
-    if choice == "q":
-        console.print("Commit cancelled.")
-        raise typer.Exit()
-    elif choice == "e":
-        # Use git's built-in editor with generated message as template
-        console.print("[cyan]Opening git editor...[/cyan]")
-        try:
-            commit_sha = repo.commit(commit_message, use_editor=True)
-        except GitError as e:
-            console.print(f"[red]Commit failed: {e}[/red]")
-            raise typer.Exit(1)
-    elif choice == "c":
-        # Commit with generated message
+    # Confirm commit or edit message (skip if --yes flag is used)
+    if yes:
+        # Automatically commit with generated message
         try:
             commit_sha = repo.commit(commit_message)
         except GitError as e:
             console.print(f"[red]Commit failed: {e}[/red]")
             raise typer.Exit(1)
     else:
-        console.print("Invalid choice. Commit cancelled.")
-        raise typer.Exit()
+        choice = typer.prompt(
+            "Choose action: (c)ommit, (e)dit message, (q)uit",
+            default="c",
+            show_default=True,
+        ).lower()
+
+        if choice == "q":
+            console.print("Commit cancelled.")
+            raise typer.Exit()
+        elif choice == "e":
+            # Use git's built-in editor with generated message as template
+            console.print("[cyan]Opening git editor...[/cyan]")
+            try:
+                commit_sha = repo.commit(commit_message, use_editor=True)
+            except GitError as e:
+                console.print(f"[red]Commit failed: {e}[/red]")
+                raise typer.Exit(1)
+        elif choice == "c":
+            # Commit with generated message
+            try:
+                commit_sha = repo.commit(commit_message)
+            except GitError as e:
+                console.print(f"[red]Commit failed: {e}[/red]")
+                raise typer.Exit(1)
+        else:
+            console.print("Invalid choice. Commit cancelled.")
+            raise typer.Exit()
 
     # Show success message
     console.print(f"[green]✓ Successfully committed: {commit_sha[:8]}[/green]")
@@ -315,7 +335,7 @@ def authenticate():
 
 @app.command()
 def models():
-    """List models available for chat in a Rich table."""
+    """List models available for chat in a table."""
     models = Copilot().models
 
     console = Console()
